@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use 5.10.1;
 use strictures 1;
@@ -34,7 +34,11 @@ use POE qw/
 ## Bot::Cobalt::Common pulls the rest of these:
 use IRC::Utils qw/ parse_mode_line /;
 
-has 'NON_RELOADABLE' => ( 
+
+use namespace::clean -except => 'meta';
+
+
+has 'NON_RELOADABLE' => (
   isa => Bool,
   ## Well, really, it's sort-of unloadable.
   ##  ... but life usually sucks when you do.
@@ -44,24 +48,24 @@ has 'NON_RELOADABLE' => (
   default => sub { 1 },
 );
 
-## We keep references to our ircobjs; core tracks these also, 
+## We keep references to our ircobjs; core tracks these also,
 ## but there is no guarantee that we're the only IRC plugin loaded.
-has 'ircobjs' => ( 
+has 'ircobjs' => (
   lazy => 1,
-  is   => 'rw', 
-  isa  => HashRef, 
+  is   => 'rw',
+  isa  => HashRef,
 
   default => sub { {} },
 );
 
 has 'flood' => (
-  is   => 'ro', 
-  isa  => Object, 
+  is   => 'ro',
+  isa  => Object,
   lazy => 1,
-  
+
   predicate => 'has_flood',
-  
-  default => sub { 
+
+  default => sub {
     my ($self) = @_;
 
     my $ccfg  = core->get_core_cfg;
@@ -109,9 +113,9 @@ sub Cobalt_unregister {
   for my $context ( keys %{ $self->ircobjs } ) {
     $self->_clear_context($context);
   }
-  
+
   logger->debug("Clean unload");
-  
+
   return PLUGIN_EAT_NONE
 }
 
@@ -122,13 +126,11 @@ sub Bot_initialize_irc {
   ## (This will override any 'Main' specified in multiserv.conf)
   ## Munge core->irc() hash into our plugin's opts()
   my $p_cfg = $core->cfg->plugins->plugin( plugin_alias($self) );
-  $p_cfg->opts->{Networks}->{Main}
-    = $core->cfg->core->irc;
+  $p_cfg->opts->{Networks}->{Main} = $core->cfg->core->irc;
 
   if (exists $p_cfg->opts->{Networks}->{'-ALL'}) {
     ## Reserved by core Auth plugin
     logger->error("-ALL is not a valid context name, disregarding.");
-
     delete $p_cfg->opts->{Networks}->{'-ALL'}
   }
 
@@ -136,7 +138,7 @@ sub Bot_initialize_irc {
   for my $context (keys %{ $p_cfg->opts->{Networks} } ) {
     ## Counter is solely to provide an informative error if cfg is fubar:
     ++$active_contexts;
-    
+
     next if defined $p_cfg->opts->{Networks}->{$context}->{Enabled}
          and $p_cfg->opts->{Networks}->{$context}->{Enabled} == 0;
 
@@ -144,7 +146,7 @@ sub Bot_initialize_irc {
 
     broadcast( 'ircplug_connect', $context );
   }
-  
+
   unless ($active_contexts) {
     logger->error("No contexts configured/enabled!");
   }
@@ -161,7 +163,7 @@ sub Bot_ircplug_connect {
   ## Called for each configured context.
   ##
   ## The sessions call the same object with different contexts in HEAP;
-  ## the handlers do some processing and relay the event from the 
+  ## the handlers do some processing and relay the event from the
   ## PoCo::IRC syndicator to the Bot::Cobalt::Core pipeline.
 
   if ($core->Servers->{$context}) {
@@ -169,7 +171,7 @@ sub Bot_ircplug_connect {
       $core->Servers->{$context}->irc->call('shutdown',
         'Reconnecting'
       );
-      
+
       $core->Servers->{$context}->clear_irc;
     }
 
@@ -179,17 +181,17 @@ sub Bot_ircplug_connect {
   }
 
   logger->debug("ircplug_connect issued for $context");
-  
+
   my $pcfg    = core->cfg->plugins->plugin( plugin_alias($self) );
   my $thiscfg = $pcfg->opts->{Networks}->{$context};
-  
+
   unless (ref $thiscfg eq 'HASH' && keys %$thiscfg) {
     logger->error("Connect issued for context without valid cfg ($context)");
     return PLUGIN_EAT_ALL
   }
 
   my $server = $thiscfg->{ServerAddr};
-  
+
   unless (defined $server) {
     logger->error("Context $context has no defined ServerAddr");
     return PLUGIN_EAT_ALL
@@ -228,7 +230,7 @@ sub Bot_ircplug_connect {
   $spawn_opts{password} = $thiscfg->{ServerPass}
     if defined $thiscfg->{ServerPass};
 
-  my $irc = POE::Component::IRC::State->spawn(%spawn_opts) 
+  my $irc = POE::Component::IRC::State->spawn(%spawn_opts)
     or logger->error("IRC component spawn() for $context failed")
     and return PLUGIN_EAT_ALL;
 
@@ -245,7 +247,7 @@ sub Bot_ircplug_connect {
   if ( $self->_spawn_for_context($context) ) {
     logger->debug("Successful session creation for context $context");
   }
-  
+
   return PLUGIN_EAT_ALL
 }
 
@@ -291,11 +293,11 @@ sub _spawn_for_context {
 sub Bot_ircplug_disconnect {
   my ($self, $core) = splice @_, 0, 2;
   my $context = ${ $_[0] };
-  
+
   logger->debug("ircplug_disconnect event caught for $context");
 
   $self->_clear_context($context);
-  
+
   return PLUGIN_EAT_ALL
 }
 
@@ -321,7 +323,7 @@ sub _clear_context {
   $irc->call('shutdown', "IRC component shut down");
 
   logger->info("Called shutdown for context $context");
-  
+
   return $context
 }
 
@@ -352,7 +354,7 @@ sub _start {
   $irc->plugin_add('NickReclaim' =>
     POE::Component::IRC::Plugin::NickReclaim->new(
         poll => $ccfg->opts->{NickRegainDelay} // 30,
-      ), 
+      ),
     );
 
   if (defined $pcfg->opts->{Networks}->{$context}->{NickServPass}) {
@@ -418,7 +420,7 @@ sub irc_001 {
 
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
-  
+
   ## set up some stuff relevant to our server context:
   irc_context($context)->connected(1);
   irc_context($context)->connectedat( time );
@@ -431,14 +433,14 @@ sub irc_001 {
   ## this may vary by server
   ## (most servers are rfc1459, some are -strict, some are ascii)
   ##
-  ## we can tell eq_irc/uc_irc/lc_irc to do the right thing by 
+  ## we can tell eq_irc/uc_irc/lc_irc to do the right thing by
   ## checking ISUPPORT and setting the casemapping if available
   my $casemap = lc( $irc->isupport('CASEMAPPING') || 'rfc1459' );
   irc_context($context)->casemap( $casemap );
-  
-  ## if the server returns a fubar value IRC::Utils automagically 
+
+  ## if the server returns a fubar value IRC::Utils automagically
   ## defaults to rfc1459 casemapping rules
-  ## 
+  ##
   ## this is unavoidable in some situations, however:
   ## misconfigured inspircd on paradoxirc gave a codepage for CASEMAPPING
   ## and a casemapping for CHARSET (which is supposed to be deprecated)
@@ -453,9 +455,9 @@ sub irc_001 {
   ##
   ## the better fix is to smack your admins with a hammer.
   my @valid_casemaps = qw/ rfc1459 ascii strict-rfc1459 /;
-  unless ($casemap ~~ @valid_casemaps) {
+  unless (grep { $_ eq $casemap } @valid_casemaps) {
     my $charset = lc( $irc->isupport('CHARSET') || '' );
-    if ($charset && $charset ~~ @valid_casemaps) {
+    if ($charset && grep { $_ eq $charset } @valid_casemaps) {
       irc_context($context)->casemap( $charset );
     }
     ## we don't save CHARSET, it's deprecated per the spec
@@ -464,6 +466,15 @@ sub irc_001 {
     ## http://www.irc.org/tech_docs/draft-brocklesby-irc-isupport-03.txt
   }
 
+  ## May have configured umodes to set:
+  my $pcfg    = core->cfg->plugins->plugin( plugin_alias($self) );
+  my $thiscfg = $pcfg->opts->{Networks}->{$context};
+
+  if (my $umode = $thiscfg->{Umodes}) {
+    logger->debug("Setting umode $umode on $context");
+    $irc->yield('mode', $irc->nick_name => $umode)
+  }
+
   my $server = $irc->server_name;
   logger->info("Connected: $context: $server");
 
@@ -476,7 +487,7 @@ sub irc_disconnected {
   my $context = $_[HEAP]->{Context};
 
   logger->warn("Disconnected: $context ($server)");
-  
+
   if ( irc_context($context) ) {
     irc_context($context)->connected(0);
     broadcast( 'disconnected', $context, $server );
@@ -488,7 +499,7 @@ sub irc_socketerr {
   my $context = $_[HEAP]->{Context};
 
   logger->warn("Socket error: $context: $err");
-  
+
   if ( irc_context($context) ) {
     irc_context($context)->connected(0);
     broadcast( 'server_error', $context, $err );
@@ -529,127 +540,12 @@ sub irc_chan_sync {
   ## check if we have a specific setting for this channel (override):
   $notify = $chan_h->{$chan}->{notify_on_sync}
     if exists $chan_h->{$chan}
-    and ref $chan_h->{$chan} eq 'HASH' 
+    and ref $chan_h->{$chan} eq 'HASH'
     and exists $chan_h->{$chan}->{notify_on_sync};
 
   $irc->yield(privmsg => $chan => $resp) if $notify;
 }
 
-sub irc_public {
-  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
-  my ($src, $where, $txt) = @_[ ARG0 .. ARG2 ];
-  
-  my $context = $heap->{Context};
-  my $irc     = $self->ircobjs->{$context};
-
-  my $casemap = core->get_irc_casemap( $context );
-  for my $mask ( core->ignore->list($context) ) {
-    ## Check against ignore list
-    ## (Ignore list should be keyed by hostmask)
-    return if matches_mask( $mask, $src, $casemap );
-  }
-
-  my $msg_obj = Bot::Cobalt::IRC::Message::Public->new(
-    context => $context,
-    src     => $src,
-    targets => $where,
-    message => $txt,
-  );
-  
-  my $floodchk = sub {
-    if ( $self->flood->check(@_) ) {
-      $self->flood_ignore($context, $src);
-      return 1
-    }
-  };
-  
-  ## Bot_public_msg / Bot_public_cmd_$cmd  
-  ## FloodChk cmds and highlights
-  if (my $cmd = $msg_obj->cmd) {
-
-    $floodchk->($context, $src) ?
-      return
-      : broadcast( 'public_cmd_'.$cmd, $msg_obj);
-
-  } elsif ($msg_obj->highlight) {
-
-    $floodchk->($context, $src) ?
-      return
-      : broadcast( 'public_msg', $msg_obj);
-
-  } else {
-    ## In the interests of keeping memory usage low on a 
-    ## large channel, we don't flood-check every incoming public 
-    ## message; plugins that respond to these may want to create 
-    ## their own Bot::Cobalt::IRC::FloodChk
-    broadcast( 'public_msg', $msg_obj );
-  }
-}
-
-sub irc_msg {
-  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
-  my ($src, $target, $txt) = @_[ARG0 .. ARG2];
-
-  my $context = $heap->{Context};
-  my $irc     = $self->ircobjs->{$context};
-
-  my $casemap = core->get_irc_casemap( $context );
-  for my $mask ( core->ignore->list($context) ) {
-    return if matches_mask( $mask, $src, $casemap );
-  }
-
-  if ( $self->flood->check($context, $src) ) {
-    my $nick = parse_user($src);
-    $self->flood_ignore($context, $src)
-      unless core->auth->level($context, $nick);
-    return
-  }
-
-  my $msg_obj = Bot::Cobalt::IRC::Message->new(
-    context => $context,
-    src     => $src,
-    targets => $target,
-    message => $txt,
-  );
-  
-  broadcast( 'private_msg', $msg_obj );
-}
-
-sub irc_snotice {
-  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
-  
-  my $context = $heap->{Context};
-
-  ## These are weird.
-  ## There should be at least a string.
-  my ($string, $target, $sender) = @_[ARG0 .. ARG2];
-  
-  ## FIXME test / POD
-  broadcast( 'server_notice', $context, $string, $target, $sender );
-}
-
-sub irc_notice {
-  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
-  my ($src, $target, $txt) = @_[ARG0 .. ARG2];
-
-  my $context = $heap->{Context};
-  my $irc     = $self->ircobjs->{$context};
-  
-  my $casemap = core->get_irc_casemap($context);
-  for my $mask ( core->ignore->list($context) ) {
-    return if matches_mask( $mask, $src, $casemap );
-  }
-
-  my $msg_obj = Bot::Cobalt::IRC::Message->new(
-    context => $context,
-    src     => $src,
-    targets => $target,
-    message => $txt,
-  );
-  
-  broadcast( 'got_notice', $msg_obj );
-}
-
 sub irc_ctcp_action {
   my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
   my ($src, $target, $txt) = @_[ARG0 .. ARG2];
@@ -672,6 +568,46 @@ sub irc_ctcp_action {
   broadcast( 'ctcp_action', $msg_obj );
 }
 
+sub irc_invite {
+  my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
+  my ($src, $channel) = @_[ARG0, ARG1];
+
+  my $context = $heap->{Context};
+  my $irc     = $self->ircobjs->{$context};
+
+  my $invite = Bot::Cobalt::IRC::Event::Channel->new(
+    context => $context,
+    src     => $src,
+    channel => $channel,
+  );
+
+  ## Bot_invited
+  broadcast( 'invited', $invite );
+}
+
+sub irc_join {
+  my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
+  my ($src, $channel) = @_[ARG0, ARG1];
+
+  my $context = $heap->{Context};
+  my $irc     = $self->ircobjs->{$context};
+
+  my $join = Bot::Cobalt::IRC::Event::Channel->new(
+    context => $context,
+    src     => $src,
+    channel => $channel,
+  );
+
+  my $me = $irc->nick_name();
+  my $casemap = core->get_irc_casemap($context);
+  if ( eq_irc($me, $join->src_nick, $casemap) ) {
+    broadcast( 'self_joined', $context, $channel );
+  }
+
+  ## Bot_user_joined
+  broadcast( 'user_joined', $join );
+}
+
 sub irc_kick {
   my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
   my ($src, $channel, $target, $reason) = @_[ARG0 .. ARG3];
@@ -701,7 +637,7 @@ sub irc_kick {
 sub irc_mode {
   my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
   my ($src, $changed_on, $modestr, @modeargs) = @_[ ARG0 .. $#_ ];
-  
+
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
 
@@ -712,7 +648,7 @@ sub irc_mode {
     mode    => $modestr,
     args    => [ @modeargs ],
   );
-  
+
   if ( $mode_obj->is_umode ) {
     ## our umode changed
     broadcast( 'umode_changed', $mode_obj );
@@ -727,22 +663,33 @@ sub irc_mode {
   broadcast( 'mode_changed', $mode_obj);
 }
 
-sub irc_topic {
-  my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
-  my ($src, $channel, $topic) = @_[ARG0 .. ARG2];
+sub irc_msg {
+  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
+  my ($src, $target, $txt) = @_[ARG0 .. ARG2];
 
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
 
-  my $topic_obj = Bot::Cobalt::IRC::Event::Topic->new(
+  my $casemap = core->get_irc_casemap( $context );
+  for my $mask ( core->ignore->list($context) ) {
+    return if matches_mask( $mask, $src, $casemap );
+  }
+
+  if ( $self->flood->check($context, $src) ) {
+    my $nick = parse_user($src);
+    $self->flood_ignore($context, $src)
+      unless core->auth->level($context, $nick);
+    return
+  }
+
+  my $msg_obj = Bot::Cobalt::IRC::Message->new(
     context => $context,
     src     => $src,
-    channel => $channel,
-    topic   => $topic,
+    targets => $target,
+    message => $txt,
   );
 
-  ## Bot_topic_changed
-  broadcast( 'topic_changed', $topic_obj );
+  broadcast( 'private_msg', $msg_obj );
 }
 
 sub irc_nick {
@@ -769,27 +716,26 @@ sub irc_nick {
   broadcast( 'nick_changed', $nchg );
 }
 
-sub irc_join {
-  my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
-  my ($src, $channel) = @_[ARG0, ARG1];
+sub irc_notice {
+  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
+  my ($src, $target, $txt) = @_[ARG0 .. ARG2];
 
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
 
-  my $join = Bot::Cobalt::IRC::Event::Channel->new(
-    context => $context,
-    src     => $src,
-    channel => $channel,
-  );
-
-  my $me = $irc->nick_name();
   my $casemap = core->get_irc_casemap($context);
-  if ( eq_irc($me, $join->src_nick, $casemap) ) {
-    broadcast( 'self_joined', $context, $channel );
+  for my $mask ( core->ignore->list($context) ) {
+    return if matches_mask( $mask, $src, $casemap );
   }
 
-  ## Bot_user_joined
-  broadcast( 'user_joined', $join );
+  my $msg_obj = Bot::Cobalt::IRC::Message->new(
+    context => $context,
+    src     => $src,
+    targets => $target,
+    message => $txt,
+  );
+
+  broadcast( 'got_notice', $msg_obj );
 }
 
 sub irc_part {
@@ -798,7 +744,7 @@ sub irc_part {
 
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
-  
+
   my $part = Bot::Cobalt::IRC::Event::Channel->new(
     context => $context,
     src     => $src,
@@ -819,6 +765,57 @@ sub irc_part {
   broadcast( 'user_left', $part );
 }
 
+sub irc_public {
+  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
+  my ($src, $where, $txt) = @_[ ARG0 .. ARG2 ];
+
+  my $context = $heap->{Context};
+  my $irc     = $self->ircobjs->{$context};
+
+  my $casemap = core->get_irc_casemap( $context );
+  for my $mask ( core->ignore->list($context) ) {
+    ## Check against ignore list
+    ## (Ignore list should be keyed by hostmask)
+    return if matches_mask( $mask, $src, $casemap );
+  }
+
+  my $msg_obj = Bot::Cobalt::IRC::Message::Public->new(
+    context => $context,
+    src     => $src,
+    targets => $where,
+    message => $txt,
+  );
+
+  my $floodchk = sub {
+    if ( $self->flood->check(@_) ) {
+      $self->flood_ignore($context, $src);
+      return 1
+    }
+  };
+
+  ## Bot_public_msg / Bot_public_cmd_$cmd
+  ## FloodChk cmds and highlights
+  if (my $cmd = $msg_obj->cmd) {
+
+    $floodchk->($context, $src) ?
+      return
+      : broadcast( 'public_cmd_'.$cmd, $msg_obj);
+
+  } elsif ($msg_obj->highlight) {
+
+    $floodchk->($context, $src) ?
+      return
+      : broadcast( 'public_msg', $msg_obj);
+
+  } else {
+    ## In the interests of keeping memory usage low on a
+    ## large channel, we don't flood-check every incoming public
+    ## message; plugins that respond to these may want to create
+    ## their own Bot::Cobalt::IRC::FloodChk
+    broadcast( 'public_msg', $msg_obj );
+  }
+}
+
 sub irc_quit {
   my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
   my ($src, $msg, $common) = @_[ARG0 .. ARG2];
@@ -837,21 +834,35 @@ sub irc_quit {
   broadcast( 'user_quit', $quit );
 }
 
-sub irc_invite {
+sub irc_snotice {
+  my ($self, $heap, $kernel) = @_[OBJECT, HEAP, KERNEL];
+
+  my $context = $heap->{Context};
+
+  ## These are weird.
+  ## There should be at least a string.
+  my ($string, $target, $sender) = @_[ARG0 .. ARG2];
+
+  ## FIXME test / POD
+  broadcast( 'server_notice', $context, $string, $target, $sender );
+}
+
+sub irc_topic {
   my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
-  my ($src, $channel) = @_[ARG0, ARG1];
-  
+  my ($src, $channel, $topic) = @_[ARG0 .. ARG2];
+
   my $context = $heap->{Context};
   my $irc     = $self->ircobjs->{$context};
 
-  my $invite = Bot::Cobalt::IRC::Event::Channel->new(
+  my $topic_obj = Bot::Cobalt::IRC::Event::Topic->new(
     context => $context,
     src     => $src,
     channel => $channel,
+    topic   => $topic,
   );
-  
-  ## Bot_invited
-  broadcast( 'invited', $invite );
+
+  ## Bot_topic_changed
+  broadcast( 'topic_changed', $topic_obj );
 }
 
 
@@ -865,17 +876,17 @@ sub Bot_rehashed {
     logger->info("Rehash received ($type), resetting ajoins");
     $self->_reset_ajoins;
   }
-  
+
   ## FIXME nickservid rehash if needed
-  
+
   return PLUGIN_EAT_NONE
 }
 
 sub Bot_ircplug_chk_floodkey_expire {
   my ($self, $core) = splice @_, 0, 2;
-  
+
   ## Lazy flood tracker cleanup.
-  ## These are just arrays of timestamps, but they gotta be cleaned up 
+  ## These are just arrays of timestamps, but they gotta be cleaned up
   ## when they're stale.
 
   $self->flood->expire if $self->has_flood;
@@ -884,7 +895,7 @@ sub Bot_ircplug_chk_floodkey_expire {
     { Event => 'ircplug_chk_floodkey_expire' },
     'IRCPLUG_CHK_FLOODKEY_EXPIRE'
   );
-  
+
   return PLUGIN_EAT_ALL
 }
 
@@ -895,11 +906,11 @@ sub Bot_ircplug_flood_rem_ignore {
   ## Internal timer-fired event to remove temp ignores.
 
   logger->info("Clearing temp ignore: $mask ($context)");
-  
-  $core->ignore->del( $context, $mask );  
+
+  $core->ignore->del( $context, $mask );
 
   broadcast( 'flood_ignore_deleted', $context, $mask );
-  
+
   return PLUGIN_EAT_ALL
 }
 
@@ -907,22 +918,22 @@ sub flood_ignore {
   ## Pass me a context and a mask
   ## Set a temporary ignore and a timer to remove it
   my ($self, $context, $mask) = @_;
-  
+
   my $corecf = core->get_core_cfg;
   my $ignore_time = $corecf->opts->{FloodIgnore} || 20;
-  
+
   $self->flood->clear($context, $mask);
-  
+
   logger->info(
     "Issuing temporary ignore due to flood: $mask ($context)"
   );
-  
+
   my $added = core->ignore->add(
     $context, $mask, "flood_ignore", __PACKAGE__
   );
 
   broadcast( 'flood_ignore_added', $context, $mask );
-  
+
   core->timer_set( $ignore_time,
     {
       Event => 'ircplug_flood_rem_ignore',
@@ -933,13 +944,13 @@ sub flood_ignore {
 
 sub _reset_ajoins {
   my ($self) = @_;
-  
+
   my $corecf  = core->get_core_cfg;
   my $servers = core->Servers;
-  
+
   CONTEXT: for my $context (keys %$servers) {
     my $chanscf = core->get_channels_cfg($context) // {};
-    
+
     my $irc = core->get_irc_obj($context) || next CONTEXT;
 
     my %ajoin;
@@ -951,7 +962,7 @@ sub _reset_ajoins {
 
     logger->debug("Removing AutoJoin plugin for $context");
     $irc->plugin_del('AutoJoin');
-    
+
     logger->debug("Loading new AutoJoin plugin for $context");
     $irc->plugin_add('AutoJoin' =>
       POE::Component::IRC::Plugin::AutoJoin->new(
@@ -962,9 +973,9 @@ sub _reset_ajoins {
         Retry_when_banned => $corecf->opts->{Chan_RetryAfterBan} // 60,
       ),
     );
- 
+
   }
-  
+
 }
 
 1;
