@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Extras::Money;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use 5.10.1;
 
@@ -140,7 +140,7 @@ sub Bot_currencyconv_rate_recv {
   my($rate,$converted);
   if ( $content =~ /<double.*>(.*)<\/double>/i ) {
     $rate = $1||1;
-    $converted = $value * $rate ;
+    $converted = sprintf("%.2f", $value * $rate);
   } else {
     broadcast( 'message', $context, $channel,
       "Failed to retrieve currency conversion ($from -> $to)"
