@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::PluginMgr;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 ## handles and eats: !plugin
 
@@ -15,6 +15,8 @@ use Scalar::Util qw/blessed/;
 
 use Try::Tiny;
 
+use namespace::clean -except => 'meta';
+
 sub new { bless [], shift }
 
 sub Cobalt_register {
@@ -44,7 +46,7 @@ sub Bot_public_cmd_plugin {
   my $context = $msg->context;
   my $chan = $msg->channel;
   my $nick = $msg->src_nick;
-  
+
   my $pcfg = core()->get_plugin_cfg( $self );
 
   ## default to superuser-only:
@@ -52,19 +54,22 @@ sub Bot_public_cmd_plugin {
 
   my $resp;
 
-  my $operation = lc($msg->message_array->[0]||'');
+  my $op = lc($msg->message_array->[0]||'');
 
   if ( core()->auth->level($context, $nick) < $required_lev ) {
     $resp = core->rpl( q{RPL_NO_ACCESS}, { nick => $nick } );
   } else {
-    unless ($operation && $operation ~~ [qw/load unload reload list/] ) {
+    unless ($op && grep { $_ eq $op } qw/load unload reload list/) {
+
       broadcast( 'message', $context, $chan,
         "Valid PluginMgr commands: list, load, unload, reload"
       );
+
+      return PLUGIN_EAT_ALL
     }
 
-    my $method = '_cmd_plug_'.lc($operation);
-    
+    my $method = '_cmd_plug_'.lc($op);
+
     if ($self->can($method)) {
       $resp = $self->$method($msg);
     } else {
@@ -84,9 +89,9 @@ sub _cmd_plug_load {
 
   ## !load Alias
   ## !load Alias Module
-  
+
   my ($alias, $module) = @{ $msg->message_array }[1,2];
-  
+
   return $self->_load($alias, $module)
 }
 
@@ -94,7 +99,7 @@ sub _cmd_plug_unload {
   my ($self, $msg) = @_;
 
   ## !unload Alias
-  
+
   my $alias = $msg->message_array->[1];
 
   return $self->_unload($alias) || "Bug; no reply from _unload"
@@ -102,9 +107,9 @@ sub _cmd_plug_unload {
 
 sub _cmd_plug_list {
   my ($self, $msg) = @_;
-  
+
   my $pluglist = core()->plugin_list;
-  
+
   my @loaded = sort keys %$pluglist;
 
   my $str = sprintf("Loaded (%d):", scalar @loaded);
@@ -132,7 +137,7 @@ sub _cmd_plug_reload {
     broadcast( 'message', $msg->context, $msg->channel,
       "Bad syntax; no plugin alias specified"
     );
-    
+
     return
 
   } elsif (!$plug_obj) {
@@ -140,10 +145,10 @@ sub _cmd_plug_reload {
     broadcast( 'message', $msg->context, $msg->channel,
       core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
         plugin => $alias,
-        err => 'No such plugin found, is it loaded?' 
+        err => 'No such plugin found, is it loaded?'
       )
     );
-    
+
     return
 
   } elsif (core()->State->{NonReloadable}->{$alias}) {
@@ -154,7 +159,7 @@ sub _cmd_plug_reload {
           err => "Plugin $alias is marked as non-reloadable",
       )
     );
-    
+
     return
   }
 
@@ -181,7 +186,7 @@ sub _unload {
 
   return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
       plugin => $alias,
-      err => 'No such plugin found, is it loaded?' 
+      err => 'No such plugin found, is it loaded?'
   ) unless $plug_obj;
 
   return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
@@ -198,13 +203,13 @@ sub _unload {
 
     ## and timers:
     core()->timer_del_alias($alias);
-      
-    return core->rpl( q{RPL_PLUGIN_UNLOAD}, 
+
+    return core->rpl( q{RPL_PLUGIN_UNLOAD},
         plugin => $alias
     )
   } else {
     return core->rpl( q{RPL_PLUGIN_UNLOAD_ERR},
-      plugin => $alias, 
+      plugin => $alias,
       err => 'Unknown core->plugin_del failure'
     )
   }
@@ -214,15 +219,15 @@ sub _unload {
 
 sub _load {
   my ($self, $alias, $module) = @_;
-  
+
   ## Called for !load / !reload
   ## Return string for IRC
-  
+
   return "Bad syntax; usage: load <alias> [module]"
     unless defined $alias;
 
   return "Plugin already loaded: $alias"
-    if $alias ~~ [ keys %{ core->plugin_list } ] ;
+    if grep { $_ eq $alias } keys %{ core()->plugin_list };
 
   return $self->_load_module($alias, $module)
     if defined $module;
@@ -235,7 +240,7 @@ sub _load {
       err => "Plugin '$alias' not found in plugins conf",
     )
   }
-  
+
   return $self->_load_module(
     $alias,
     $plugin_cfg->module
@@ -257,7 +262,7 @@ sub _load_module {
 
   if ($err) {
     logger->warn("Plugin load failure; $err");
-    
+
     Bot::Cobalt::Core::Loader->unload($module);
 
     return core->rpl( q{RPL_PLUGIN_ERR},
@@ -275,9 +280,9 @@ sub _load_module {
       core()->State->{NonReloadable}->{$alias} = 1;
       logger->debug("$alias flagged non-reloadable");
     }
-      
+
     my $modversion = $obj->can('VERSION') ? $obj->VERSION : 1 ;
-      
+
     return core->rpl( q{RPL_PLUGIN_LOAD},
       plugin  => $alias,
       module  => $module,
@@ -287,7 +292,7 @@ sub _load_module {
     ## Couldn't plugin_add
     logger->error("plugin_add failure for $alias");
 
-    ## run cleanup  
+    ## run cleanup
     Bot::Cobalt::Core::Loader->unload($module);
 
     delete core()->PluginObjects->{$obj};
@@ -322,8 +327,8 @@ Bot::Cobalt::Plugin::PluginMgr - IRC plugin manager
 
 This is a fairly simplistic online plugin manager.
 
-Required level defaults to 9999 (standard-auth superusers) unless 
-the LevelRequired option is specified in PluginMgr's plugins.conf 
+Required level defaults to 9999 (standard-auth superusers) unless
+the LevelRequired option is specified in PluginMgr's plugins.conf
 B<Opts> directive:
 
   PluginMgr:
